/*
   aux/functions.h
   This file is part of the Osirion project and is distributed under
   the terms of the GNU General Public License version 2
*/

#ifndef __INCLUDED_AUX_FUNCTIONS_H__
#define __INCLUDED_AUX_FUNCTIONS_H__

#include <string>


/// auxiliary functions
namespace aux
{

/// append an "s" to a word, depending on the amount
const std::string plural(const char * word, size_t n);

/// append an "s" to a word, depending on the amount
inline const std::string plural(const std::string & word, size_t n) { return plural(word.c_str(), n); }

/// prepend the "a" or "an" article to a word
const std::string article(const char * word);

inline const std::string article(const std::string & word) { return article(word.c_str()); }

inline bool is_base_color_code(char const *c) { return ((*c == '^') && (*(c+1) >= '0') && (*(c+1) <= '7')); }

inline bool is_core_color_code(char const *c) { return ((*c == '^') && (*(c+1) >= 'A') && (*(c+1) <= 'Z')); }

inline bool is_color_code(char const *c) { return (is_base_color_code(c) || is_core_color_code(c)); }

/// length of a string, excluding color codes
size_t text_length(const std::string &text);

/// prepend spaces to a string up to the desired lenght, excluding color codes
const std::string pad_left(const std::string &text, size_t n);

/// append spaces to a string up to the desired lenght, excluding color codes
const std::string pad_right(const std::string &text, size_t n);

/// convert a string to lowercase
void to_lowercase(std::string &text);

/// return text, converted to lowercase
const std::string lowercase(const std::string &text);

/// return text, stripped of color codes
const std::string text_strip(const std::string &text);

/// return text, stripped of color codes and converted to lowercase
const std::string text_strip_lowercase(const std::string &text);

/// trim leading ad trailing spaces from a string
void trim(std::string &text);

/// replaces double quotes by single quotes
void strip_quotes(std::string &text);

/// convert a string to a valid label string
/** trim leading and trealing spaces, convert remaining spaces to underscores, and make lowercase
 * remove any non-alphanumeric character
 */
void to_label(std::string &text);

}

#endif // __INCLUDED_AUX_FUNCTIONS_H__
