/*
   client/client.h
   This file is part of the Osirion project and is distributed under 
   the terms and conditions of the GNU General Public License version 2 
*/

#ifndef __INCLUDED_CLIENT_H__
#define __INCLUDED_CLIENT_H__

#include "core/application.h"
#include "client/view.h"

/// client part of the engine
namespace client {

/// run the client application
void run(int count, char **arguments);

/// client application implementation
class Client : public core::Application
{
public:
	/// initialize the client
	virtual void init(int count, char **arguments);

	/// run the client
	virtual void run();

	/// shutdown the client
	virtual void shutdown();

	/// quit the client
	virtual void quit(int status);

	/// sound notifications from the core
	virtual void notify_sound(const char * name);

	/// text notifications from the core
	virtual void notify_message(const core::Message::Channel channel, const std::string &message);

	/// text notifications from the client
	void notify_message(const std::string &message);

	/// text notifications from the client
	void notify_message(const char *message);

	/// remove sound source notification
	virtual void notify_remove_sound(size_t source);

	/// clear zone notification
	virtual void notify_zonechange();

	/// connect notification
	virtual void notify_connect();

	/// disconnect notification
	virtual void notify_disconnect();

	/// the main client view
	inline View *view() { return client_view; }

protected:
	/// run a client frame
	virtual void frame(unsigned long timestamp);

private:

	static void func_snd_restart(std::string const &args);
	static void func_r_restart(std::string const &args);
	static void func_ui_chat(std::string const &args);
	static void func_ui_chatsmall(std::string const &args);

	View		*client_view;

	unsigned long	previous_timestamp;
};

Client *client();

}

#endif // __INCLUDED_CLIENT_H__

