/*
   intro/intro.cc
   This file is part of the Osirion project and is distributed under 
   the terms of the GNU General Public License version 2 
*/

#include "intro/intro.h"
#include "core/core.h"
#include "core/parser.h"
#include "filesystem/filesystem.h"
#include "filesystem/inifile.h"
#include "math/color.h"
#include "sys/sys.h"

namespace intro {

Intro::Intro() : core::Module("intro", "Introduction", false)
{
	intro_zone = 0;
	intro_convoy = 0;
}

Intro::~Intro()
{
}

void Intro::init()
{
	/// intialize a single zone for the introduction
	intro_zone = new core::Zone("intro");
	intro_zone->set_name("Introduction");
	intro_zone->set_sky("sky");
	core::Zone::add(intro_zone);

	intro_convoy = new Convoy(intro_zone);

	if (!load_world()) {
		abort();
		return;
	}
}

bool Intro::load_world()
{
	std::string filename("intro");

	filesystem::IniFile ini;
	ini.open(filename);

	if (!ini.is_open()) {
		con_error << "Could not open " << ini.name() << std::endl;
		return false;
	}

	std::string strval;
	core::EntityGlobe *globe = 0;
	math::Color color;
	math::Vector3f v;
	float f;
	bool b;
	
	while (ini.getline()) {

		if (ini.got_section()) {
			if (ini.got_section("intro")) {
				continue;
	
			} else if (ini.got_section("convoy")) {
				continue;
	
			} else if (ini.got_section("globe")) {
				globe = new core::EntityGlobe();
				globe->set_zone(intro_zone);
	
			} else {
				ini.unknown_section();
			}
		} else if (ini.got_key()) {

			if (ini.in_section("intro")) {
				if (ini.got_key_string("sky", strval)) {
					intro_zone->set_sky(strval);
					continue;

				} else if (ini.got_key()) {
					ini.unkown_key();
				}

			} else if (ini.in_section("convoy")) {
				if (ini.got_key_color("color", color)) {
					intro_convoy->set_color(color);

				} else if (ini.got_key_color("colorsecond", color)) {
					intro_convoy->set_color_second(color);

				} else if (ini.got_key_vector3f("location", v)) {
					intro_convoy->set_location(v);

				} else if (ini.got_key_float("direction", f)) {
					intro_convoy->change_direction(f);

				} else if (ini.got_key_float("speed", f)) {
					intro_convoy->set_speed(f);

				} else if (ini.got_key_string("ship", strval)) {
					intro_convoy->add(strval);

				} else if (ini.got_key()) {
					ini.unkown_key();
				}

			} else if (ini.in_section("globe")) {
				if (core::Parser::got_entity_key(ini, globe)) {
					continue;
				} else if (ini.got_key_string("texture", globe->entity_texture)) {
					continue;
				} else if (ini.got_key_float("rotationspeed", globe->entity_rotationspeed)) {
					continue;
				} else if (ini.got_key_bool("bright", b)) {
					if (b) { globe->set_flag(core::Entity::Bright); }
				} else if (ini.got_key()) {
					ini.unkown_key();
				}
			}
		}
	}

	return true;
}

void Intro::player_connect(core::Player *player)
{
	player->set_zone(intro_zone);
}

void Intro::player_disconnect(core::Player *player)
{
}

void Intro::frame(float seconds)
{
	if (intro_convoy) {
		intro_convoy->frame(seconds);
	}
}

void Intro::shutdown()
{
	intro_zone = 0;

	if (intro_convoy) {
		delete intro_convoy;
		intro_convoy = 0;
	}
}

}

