/*
   model/engine.h
   This file is part of the Osirion project and is distributed under
   the terms of the GNU General Public License version 2
*/

#ifndef __INCLUDED_MODEL_ENGINE_H__
#define __INCLUDED_MODEL_ENGINE_H__

#include "math/vector3f.h"
#include "math/color.h"

namespace model
{

/// a spacecraft engine
class Engine
{
public:
	Engine();
	
	Engine(math::Vector3f const & location);
	~Engine();
	
	inline math::Vector3f const & location() const
	{
		return engine_location;
	}
	
	inline float radius() const
	{
		return engine_radius;
	}
	
	inline unsigned int flare() const
	{
		return engine_flare;
	}
	
	inline unsigned int texture() const
	{
		return render_texture;
	}

	inline bool noflare() const
	{
		return engine_noflare;
	}

	inline bool notrail() const
	{
		return engine_notrail;
	}
	
	math::Vector3f		engine_location;
	float			engine_radius;
	unsigned int		engine_flare;


	bool			engine_noflare;
	bool			engine_notrail;
	
	unsigned int		render_texture;
};

}

#endif // __INCLUDED_MODEL_ENGINE_H__

